#include <qlabel.h>
#include <qmultilineedit.h>
#include <qpushbutton.h>

#include <kapp.h>
#include <kdialog.h>
#include <dcopclient.h>

#include "dcopdemowidget.h"
#include "dcopdemowidget.moc"

DCOPDemoWidget::DCOPDemoWidget()
    : QVBox( 0, "DCOPDemoWidget" ),
      DCOPObject( "DCOPDemoIface" )
{
    createGUI();

    // Register with DCOP
    if ( !kapp->dcopClient()->isRegistered() ) {
	kapp->dcopClient()->registerAs( "dcopifacedemo" );
	kapp->dcopClient()->setDefaultObject( objId() );
    }
}

DCOPDemoWidget::~DCOPDemoWidget()
{

}

void DCOPDemoWidget::setNumVal( int num )
{
    output( QString( "setNumVal( \"%1\" )" ).arg( num ) );
    this->num = num;
}

void DCOPDemoWidget::setStrVal( const QString &str )
{
    output( QString( "setStrVal( \"%1\" )" ).arg( str ) );
    this->str = str;
}


void DCOPDemoWidget::dump()
{
    output( QString( "String: \"%1\", Number: \"%2\"" ).arg( str ).arg( num ) );
}

void DCOPDemoWidget::createGUI()
{
    setSpacing( KDialog::spacingHint() );
    setMargin( KDialog::marginHint() );

    (void) new QLabel( "<font size=\"+2\"><b>DCOP Interface Demo</b></font>",
		       this, "Title" );

    log = new QMultiLineEdit( this, "LogView" );
    log->setReadOnly( true );

    run = new QPushButton( "&Dump Values", this, "DumpButton" );
    connect( run, SIGNAL( clicked() ), SLOT( dump() ) );
}

void DCOPDemoWidget::output( const QString &msg )
{
    log->insertLine( msg );
    log->setCursorPosition( log->numLines() - 1, 0 );
}


// Local Variables:
// c-basic-offset: 4
// End:

