#include <qlabel.h>
#include <qlineedit.h>
#include <qmultilineedit.h>
#include <qpushbutton.h>
#include <kdialog.h>

#include <kjs/ustring.h>
#include <kjs/types.h>

#include "jsembed.h"
#include "jsembed.moc"

KJS::Completion JSEmbedPrint::execute( const KJS::List &args )
{
    KJS::KJSO v = args[0];
    KJS::String s = v.toString();
    QString qs = s.value().cstring().c_str();
    win->output( qs );

    return KJS::Completion( KJS::Normal );
}

JSEmbed::JSEmbed()
    : QVBox( 0, "JSEmbed" )
{
    createGUI();
    output( QString("-- Enter a JS expression and press enter --") );

    js = new KJScript();
    KJS::Imp *imp = js->globalObject();
    imp->put( "print", KJS::Function( new JSEmbedPrint( this ) ) );
}

JSEmbed::~JSEmbed()
{
    delete js;
}

void JSEmbed::execute()
{
    QString code = cmd->text();
    output( QString( "kjs> %1" ).arg( code ) );

    KJS::UString codeStr( code.local8Bit().data() );
    bool ok = js->evaluate( codeStr );
    if ( !ok ) {
	QString err = ( js->errorType() ? js->errorMsg() : "Ok" );
	output( err );
	return;
    }
    
    KJS::Imp *val = js->returnValue();
    if ( !val ) {
	output( "No Return Value" );
	return;
    }

    KJS::String s = val->toString();
    KJS::UString us = s.value();
    output( QString(us.ascii()) );
}

void JSEmbed::createGUI()
{
    setSpacing( KDialog::spacingHint() );
    setMargin( KDialog::marginHint() );

    (void) new QLabel( "<font size=\"+2\"><b>Embedded KJS Interpreter Demo</b></font>",
		       this, "Title" );
    log = new QMultiLineEdit( this, "LogView" );
    log->setReadOnly( true );
    cmd = new QLineEdit( this, "CmdEdit" );
    cmd->setFocus();
    run = new QPushButton( "&Run Command", this, "RunButton" );

    connect( cmd, SIGNAL( returnPressed() ), run, SLOT( animateClick() ) );
    connect( run, SIGNAL( clicked() ), SLOT( execute() ) );
}

void JSEmbed::output( const QString &msg )
{
    log->insertLine( msg );
    log->setCursorPosition( log->numLines() - 1, 0 );
}


// Local Variables:
// c-basic-offset: 4
// End:

